# rtt-console

The console allows you to connect to the MCU with the installed RTT server.
The main advantage of the program is a more convenient command input in comparison with Segger RTT Viewer
and the like.

Usage:

```bash
rtt-console -t STM32F407VE
```

![img](https://github.com/Mcublog/rtt-console/raw/master/doc/img.gif)
